#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
""" Tests for core sampler """

import logging
import sys
from io import StringIO
from logging import getLogger
from unittest.mock import patch

from core_sampler.core_sampler import main

logger = logging.getLogger("core_sampler")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))

import pytest


def test_gets_eb_as_expected():
    """
    Do we get the output we expect for this 21A-409 execution block?

    :return:
    """
    sys.argv.append("-e")
    sys.argv.append("21A-409.sb39530397.eb39561636.59309.07888592593")

    with patch("sys.stdout", new=StringIO()) as fake_out:
        main()
        output = fake_out.getvalue()
        rows = output.split("\n")

        found = False
        for row in rows:
            if "156759763" in row and "23142018" in row:
                found = True
                break
        assert found

        if len(rows) == 181:
            # sometimes we get an extra blank line
            assert len(rows[-1]) == 0
        else:
            assert len(rows) == 180

    sys.argv.pop()
    sys.argv.pop()


def test_gets_project_as_expected():
    """
    Do we get the output we expect for 20A-465?

    :return:
    """
    sys.argv.append("-p")
    sys.argv.append("20A-465")

    with patch("sys.stdout", new=StringIO()) as fake_out:
        main()
        output = fake_out.getvalue()
        rows = output.split("\n")
        if len(rows) == 705:
            # sometimes we get an extra blank line
            assert len(rows[-1]) == 0
        else:
            assert len(rows) == 704
        found = False
        for row in rows:
            if "uid____evla_bdf_1589728351957.bdf" in row and "121847" in row:
                found = True
                break
        assert found

    sys.argv.pop()
    sys.argv.pop()
